@@ -7,8 +7,8 @@ from .formating import (Collect, ImageToTensor, ToNumpy, ToPIL, ToTensor,
                         Transpose, to_tensor)
 from .loading import LoadImageFromFile
 from .transforms import (CenterCrop, ColorJitter, Lighting, RandomCrop,
-                         RandomFlip, RandomGrayscale, RandomResizedCrop,
-                         Resize)
+                         RandomErasing, RandomFlip, RandomGrayscale,
+                         RandomResizedCrop, Resize)
 
 __all__ = [
     'Compose', 'to_tensor', 'ToTensor', 'ImageToTensor', 'ToPIL', 'ToNumpy',
@@ -17,5 +17,5 @@ __all__ = [
     'RandomGrayscale', 'Shear', 'Translate', 'Rotate', 'Invert',
     'ColorTransform', 'Solarize', 'Posterize', 'AutoContrast', 'Equalize',
     'Contrast', 'Brightness', 'Sharpness', 'AutoAugment', 'SolarizeAdd',
-    'Cutout', 'RandAugment', 'Lighting', 'ColorJitter'
+    'Cutout', 'RandAugment', 'Lighting', 'ColorJitter', 'RandomErasing'
 ]
